@@ -42,6 +42,12 @@ jest.mock('grafana/app/core/utils/datemath', () => {
   };
 }, {virtual: true});
 
+jest.mock('grafana/app/core/utils/kbn', () => {
+  return {
+    round_interval: n => n,
+  };
+}, {virtual: true});
+
 jest.mock('grafana/app/core/table_model', () => {
   return class TableModel {
     constructor() {
